@@ -138,8 +138,7 @@ def mail_exchanger_lookup(domain, metrics=False):
         mx_hosts = lookup_domain(domain)
         mtimes['dns_lookup'] += time.time() - bstart
         if mx_hosts is None:
-            #commenting out falses in the cache, be sure to monitor backend load. - Jason
-            #mx_cache[domain] = False
+            mx_cache[domain] = False
             return None, mtimes
 
     # test connecting to the mx exchanger
@@ -147,8 +146,7 @@ def mail_exchanger_lookup(domain, metrics=False):
     mail_exchanger = connect_to_mail_exchanger(mx_hosts)
     mtimes['mx_conn'] = time.time() - bstart
     if mail_exchanger is None:
-        #commenting out falses in the cache, be sure to monitor backend load. - Jason
-        #mx_cache[domain] = False
+        mx_cache[domain] = False
         return None, mtimes
 
     # valid mx records, connected to mail exchanger, return True
